Server API
==========

.. automodule:: slicer_package_manager
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   slicer_package_manager.api
   slicer_package_manager.models

Submodules
----------

slicer\_package\_manager.constants module
-----------------------------------------

.. automodule:: slicer_package_manager.constants
   :members:
   :undoc-members:
   :show-inheritance:

slicer\_package\_manager.utilities module
-----------------------------------------

.. automodule:: slicer_package_manager.utilities
   :members:
   :undoc-members:
   :show-inheritance:
